@@ -1,15 +1,11 @@
-__version__ = '0.8.0'
+__version__ = '0.8.1'
 
 from ._mpservice import Server, Servlet
 from ._mpservice import TimeoutError, EnqueueTimeout, TotalTimeout
 from ._mperror import MPError
-from ._server_process import ServerProcess
-from ._http import run_app
 
 __all__ = [
     'Servlet', 'Server',
-    'ServerProcess',
     'MPError',
     'TimeoutError', 'EnqueueTimeout', 'TotalTimeout',
-    'run_app',
 ]
